@@ -5,15 +5,14 @@ import os
 from .http import check
 from .cjson import set_config
 global __version__, __functions__
-__version__ = "1.0.0"
+__version__ = "1.0.1"
 #Functions
 __functions__ = f'''
 Capylang v{__version__} help.
 Running Capylang directly results in invalid class usage. To be provided with assistance while using Capylang, run capy.help() or see the commands below.
 
-capy.set()
-Sets a setting for Capylang.
-An example is capy.set('auto_update',True), which sets auto updating to true.
+capy.auto_update()
+Sets the auto update setting. True or False.
 
 capy.help()
 1. The function prints out all the functions in the current module.
